==> haskell-monadplus-1.4.2-16-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-monadplus.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 monadplus
version:              1.4.2
visibility:           public
id:                   monadplus-1.4.2-8xXVl38Vlv1GWsqSCyK3bO
key:                  monadplus-1.4.2-8xXVl38Vlv1GWsqSCyK3bO
license:              BSD-3-Clause
maintainer:           Hans Hoglund <hans@hanshoglund.se>
author:               Hans Hoglund
synopsis:             Haskell98 partial maps and filters over MonadPlus.
description:
    Filtering and folding over arbitrary `MonadPlus` instances.
    This package generalizes many common stream operations such as
    `filter`, `catMaybes` etc.

category:             Control
abi:                  35a5b8a807bcea250e204286f1561e7f
exposed:              True
exposed-modules:      Control.Applicative.Alternative Control.Monad.Plus
import-dirs:          /usr/lib/ghc-8.8.3/site-local/monadplus-1.4.2
library-dirs:         /usr/lib/ghc-8.8.3/site-local/monadplus-1.4.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/monadplus-1.4.2
hs-libraries:         HSmonadplus-1.4.2-8xXVl38Vlv1GWsqSCyK3bO
depends:              base-4.13.0.0
haddock-interfaces:   /usr/share/doc/haskell-monadplus/html/monadplus.haddock
haddock-html:         /usr/share/doc/haskell-monadplus/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-monadplus-1.4.2-17-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-monadplus.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 monadplus
version:              1.4.2
visibility:           public
id:                   monadplus-1.4.2-JYe0rtHXVx39U0WBVya9aU
key:                  monadplus-1.4.2-JYe0rtHXVx39U0WBVya9aU
license:              BSD-3-Clause
maintainer:           Hans Hoglund <hans@hanshoglund.se>
author:               Hans Hoglund
synopsis:             Haskell98 partial maps and filters over MonadPlus. 
description:
    Filtering and folding over arbitrary `MonadPlus` instances.
    This package generalizes many common stream operations such as
    `filter`, `catMaybes` etc.

category:             Control
abi:                  ed18fcbaae8f11497a907e76cccd9816
exposed:              True
exposed-modules:      Control.Applicative.Alternative Control.Monad.Plus
import-dirs:          /usr/lib/ghc-8.10.1/site-local/monadplus-1.4.2
library-dirs:         /usr/lib/ghc-8.10.1/site-local/monadplus-1.4.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/monadplus-1.4.2
hs-libraries:         HSmonadplus-1.4.2-JYe0rtHXVx39U0WBVya9aU
depends:              base-4.14.0.0
haddock-interfaces:   /usr/share/doc/haskell-monadplus/html/monadplus.haddock
haddock-html:         /usr/share/doc/haskell-monadplus/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
